@@ -53,7 +53,7 @@ from saintBioutils.utilities.file_io import make_output_directory
 from cazy_webscraper.sql import sql_orm
 
 
-__version__ = "2.0.13"
+__version__ = "2.1.0"
 
 VERSION_INFO = f"cazy_webscraper version: {__version__}"
 
@@ -76,7 +76,7 @@ def closing_message(job, start_time, args):
 
     if args.verbose:
         logger.info(
-            "Finished scraping CAZy. Terminating program.\n"
+            f"====================={job}=====================\n"
             f"Scrape initated at {start_time}\n"
             f"Scrape finished at {end_time}\n"
             f"Total run time: {total_time}"
@@ -86,7 +86,6 @@ def closing_message(job, start_time, args):
     else:
         print(
             f"====================={job}=====================\n"
-            "Finished scraping CAZy\n"
             f"Scrape initated at {start_time}\n"
             f"Scrape finished at {end_time}\n"
             f"Total run time: {total_time}\n"
@@ -121,7 +120,7 @@ def connect_existing_db(args, time_stamp, start_time):
         sys.exit(1)
 
     try:
-        connection = sql_orm.get_db_connection(args.database, args, new=False)
+        connection = sql_orm.get_db_connection(args.database, args.sql_echo, new=False)
         logger.info("Opened connection to local CAZyme database")
     except Exception:
         logger.error(
